// -*- c++ -*-
/*
 *  USBSink - blackfilelist.h
 *
 *  Copyright (C) 2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _BLACK_FILE_LIST_H_
#define _BLACK_FILE_LIST_H_

#include "filelist.h"
#include "filelistbase.h"

#include <list>
#include <tr1/memory>

#include <gtkmm/textbuffer.h>

namespace USBSink
{

namespace TaskHandling
{

class BlackFileList;

typedef std::tr1::shared_ptr<BlackFileList> SharedBlackFileList;

static const Glib::ustring black_file_list_type_string = "black_file_list";

class BlackFileList : public FileListBase
{
 public:

  friend class FileListRegistry;

  virtual void add(SharedItem& new_item);

  virtual void save() const;

  virtual Glib::ustring get_type_string() const;

  virtual bool filter(const Glib::ustring& str) const;

  virtual void set_items(const std::list<SharedItem>& new_items);

 protected:

   explicit BlackFileList(const Glib::ustring& name);
   explicit BlackFileList(const Glib::ustring& name,
                          const Glib::RefPtr<Gtk::TextBuffer>& text_buffer);

   static SharedFileList create(const Glib::ustring& name);

   static SharedFileList create(
     const Glib::ustring& name,
     const Glib::RefPtr<Gtk::TextBuffer>& text_buffer);

  static SharedFileList create_from_file(const Glib::ustring& path);

  virtual void on_registry_request_response(SharedItem& item);

 private:

  static Glib::ustring type_string_;
};

/* Implementation of BlackFileList's inline functions */

inline Glib::ustring
BlackFileList::get_type_string() const
{
  return type_string_;
}

} // namespace TaskHandling

} // namespace USBSink

#endif // _BLACK_FILE_LIST_H_
