/*
 *  USBSink - filelistitem.cc
 *
 *  Copyright (C) 2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "filelistitem.h"

#include <algorithm>
#include <functional>
#include <list>

#include <glib.h>

namespace USBSink
{

namespace TaskHandling
{

using std::list;

FileListItem::FileListItem(const Glib::ustring& regexp)
  :
  value_(regexp),
  regexp_(regexp, pcrecpp::UTF8())
{
}

SharedFileListItem
FileListItem::create(const Glib::ustring& regexp)
{
  SharedFileListItem new_item(new FileListItem(regexp));

  return new_item;
}

/**
 * @param str UTF-8 string to match.
 *
 * @return true if the specified string matches the regular expression value
 * of this FileListItem, false otherwise.
 */
bool
FileListItem::match(const Glib::ustring& str) const
{
  return (regexp_.FullMatch(str.c_str()));
}

} // namespace TaskHandling

} // namespace USBSink
