// -*- c++ -*-
/*
 *  USBSink - globalstrings.h
 *
 *  Copyright (C) 2005-2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _GLOBALSTRINGS_H_
#define _GLOBALSTRINGS_H_

#include <glib/gutils.h>  // for G_DIR_SEPARATOR_S
#include <glibmm/ustring.h>


namespace USBSink
{

/*
 * The idea is taken from Daniel Elstner's Regexxer.
 * Thanks to the GNU compiler/linker, these namespaced string constants
 * are no less efficient than string literals or preprocessor #defines.
 * The final executable contains exactly one copy of each string literal,
 * so there's no need to define them in a separate object file.
 */

const char *const rc_dir = ".config";
const char *const task_dir = "tasks";
const char *const file_list_dir = "file_lists";

const char *const file_list_format_left_terminator = "<";
const char *const file_list_format_right_terminator = ">";

const char *const glade_aboutdialog_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "aboutdialog.glade";
const char *const glade_addfilesdialog_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "addfilesdialog.glade";
const char *const glade_filelisteditor_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "filelisteditor.glade";
const char *const glade_flashdrivesdialog_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "flashdrivesdialog.glade";
const char *const glade_logviewdialog_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "logviewdialog.glade";
const char *const glade_mainwindow_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "mainwindow.glade";
const char *const glade_newtaskdialog_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "newtaskdialog.glade";
const char *const glade_prefdialog_filename
  = USBSINK_PKGDATADIR G_DIR_SEPARATOR_S "prefdialog.glade";

} // namespace USBSink

#endif
