// -*- c++ -*-
/*
 *  USBSink - taskfileparser.h
 *
 *  Copyright (C) 2006 Marko Anastasov
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _TASK_FILE_PARSER_
#define _TASK_FILE_PARSER_

#include <list>
#include <string>
#include <tr1/memory>

#include <glibmm/markup.h>

namespace Gnome { namespace Vfs { class Uri; } }

namespace USBSink
{

namespace TaskHandling
{

Glib::ustring
markup_error_code_to_string(Glib::MarkupError::Code code);

class IgnoreFile;
class Task;
class FileList;

class FileParser : public Glib::Markup::Parser
{
 public:

  FileParser();
  ~FileParser();
  
  void save_task(const std::tr1::shared_ptr<Task>& task);
  
  sigc::signal< void, std::tr1::shared_ptr<Task>& , bool > signal_task_loaded;

 protected:

  //TODO: move this to task.h
  class TaskArgs
  {
  public:
    TaskArgs() {}
    
    int id;
    Glib::ustring name;
    std::string drive_udi;
    DataFlow data_flow;
    std::tr1::shared_ptr<FileList> file_list;
    StartTimeOption when_to_start;
    int timeout;
    std::list< Glib::RefPtr<Gnome::Vfs::Uri> > src_files;
    Glib::ustring target_dir;
    bool last_state;
    
    std::tr1::shared_ptr<Task> create_task();
  };

  // reading: implemented Glib::Markup::Parser virtual functions
  //
  void on_start_element(Glib::Markup::ParseContext& context,
                        const Glib::ustring& element_name,
                        const Glib::Markup::Parser::AttributeMap& attributes);

  void on_end_element(Glib::Markup::ParseContext& context,
                      const Glib::ustring& element_name);

  void on_text(Glib::Markup::ParseContext& context,
               const Glib::ustring& text);

  void on_error(Glib::Markup::ParseContext& context,
                const Glib::MarkupError& error);

  // Task property-level writing functions
  //
  void write_task_id(const int id);
  void write_task_name(const Glib::ustring& value);
  void write_drive_udi(const Glib::ustring& value);
  void write_data_flow_type(DataFlow flow);
  // void write_file_list_type(SharedFileList& list);
  void write_start_option(StartTimeOption sto);
  void write_timeout(int value);
  void write_source_files(
    const std::list< Glib::RefPtr<Gnome::Vfs::Uri> >& src_files);
  void write_target_dir(const Glib::ustring& value);
  void write_last_state(bool value);

  // XML element-level write functions
  //
  void write_start_element(int level, const Glib::ustring& name);

  void write_end_element(int level, const Glib::ustring& name);

  void write_attribute(const Glib::ustring& name, const Glib::ustring& value);

 private:

  Glib::RefPtr<Glib::IOChannel> channel_;
  TaskArgs* task_args_;
};

} // namespace TaskHandling

} // namespace USBSink

#endif // _TASK_FILE_PARSER_
